# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 07:52:36 2018 from module list in Acme::CPANLists::Import::PerlAdvent::2014_12_16 version 0.001.

package Acme::CPANModules::Import::PerlAdvent::2014_12_16;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {
  description => "This list is generated by extracting module names mentioned in [http://perladvent.org/2014/2014-12-16.html] (retrieved on 2016-11-06). Visit the URL for the full contents.",
  entries     => [
                   { module => "Code::TidyAll" },
                   { module => "Code::TidyAll::Plugin::CSSUnminifier" },
                   { module => "Code::TidyAll::Plugin::Go" },
                   { module => "Code::TidyAll::Plugin::JSBeautify" },
                   { module => "Code::TidyAll::Plugin::JSHint" },
                   { module => "Code::TidyAll::Plugin::JSLint" },
                   { module => "Code::TidyAll::Plugin::JSON" },
                   { module => "Code::TidyAll::Plugin::MasonTidy" },
                   { module => "Code::TidyAll::Plugin::PHPCodeSniffer" },
                   { module => "Code::TidyAll::Plugin::PerlCritic" },
                   { module => "Code::TidyAll::Plugin::PerlTidy" },
                   { module => "Code::TidyAll::Plugin::PodChecker" },
                   { module => "Code::TidyAll::Plugin::PodSpell" },
                   { module => "Code::TidyAll::Plugin::SVG" },
                   { module => "Code::TidyAll::Plugin::SortLines" },
                   { module => "Code::TidyAll::Plugin::SortLines::Naturally" },
                   { module => "Code::TidyAll::Plugin::UniqueLines" },
                   { module => "File::Zglob" },
                   { module => "Perl::Tidy" },
                 ],
  summary     => "Modules mentioned in Perl Advent Calendar 2014 (day 16)",
};

1;
# ABSTRACT: Modules mentioned in Perl Advent Calendar 2014 (day 16)

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::PerlAdvent::2014_12_16 - Modules mentioned in Perl Advent Calendar 2014 (day 16)

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::Import::PerlAdvent::2014_12_16 (from Perl distribution Acme-CPANModulesBundle-Import-PerlAdvent-2014), released on 2018-09-22.

=head1 DESCRIPTION

Modules mentioned in Perl Advent Calendar 2014 (day 16).

This list is generated by extracting module names mentioned in [http://perladvent.org/2014/2014-12-16.html] (retrieved on 2016-11-06). Visit the URL for the full contents.

=head1 INCLUDED MODULES

=over

=item * L<Code::TidyAll>

=item * L<Code::TidyAll::Plugin::CSSUnminifier>

=item * L<Code::TidyAll::Plugin::Go>

=item * L<Code::TidyAll::Plugin::JSBeautify>

=item * L<Code::TidyAll::Plugin::JSHint>

=item * L<Code::TidyAll::Plugin::JSLint>

=item * L<Code::TidyAll::Plugin::JSON>

=item * L<Code::TidyAll::Plugin::MasonTidy>

=item * L<Code::TidyAll::Plugin::PHPCodeSniffer>

=item * L<Code::TidyAll::Plugin::PerlCritic>

=item * L<Code::TidyAll::Plugin::PerlTidy>

=item * L<Code::TidyAll::Plugin::PodChecker>

=item * L<Code::TidyAll::Plugin::PodSpell>

=item * L<Code::TidyAll::Plugin::SVG>

=item * L<Code::TidyAll::Plugin::SortLines>

=item * L<Code::TidyAll::Plugin::SortLines::Naturally>

=item * L<Code::TidyAll::Plugin::UniqueLines>

=item * L<File::Zglob>

=item * L<Perl::Tidy>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-PerlAdvent-2014>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-PerlAdvent-2014>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-PerlAdvent-2014>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
