# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 07:52:33 2018 from module list in Acme::CPANLists::Import::PerlAdvent::2014 version 0.001.

package Acme::CPANModules::Import::PerlAdvent::2014;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {
  description => "This list is generated by extracting module names mentioned in [http://perladvent.org/2014/] (retrieved on 2016-11-06). Visit the URL for the full contents.",
  entries     => [
                   { module => "File::Temp" },
                   { module => "Test::TempDir::Tiny" },
                   { module => "DBIx::Class" },
                   { module => "DBIx::Class::Schema::Loader" },
                   { module => "Mac::Safari::JavaScript" },
                   { module => "HTTP::Tiny" },
                   { module => "PSGI" },
                   { module => "Plack" },
                   { module => "Plack::Builder" },
                   { module => "Plack::Middleware" },
                   { module => "Plack::Util" },
                   { module => "List::UtilsBy" },
                   { module => "Sub::Name" },
                   { module => "Sub::Util" },
                   { module => "DBI" },
                   { module => "Test::DatabaseRow" },
                   { module => "Test::More" },
                   { module => "Time::Limit" },
                   { module => "PPI" },
                   { module => "Perl::Metrics::Simple" },
                   { module => "Mojo::Collection" },
                   { module => "Mojo::Pg" },
                   { module => "Mojo::Pg::Database" },
                   { module => "Mojo::Pg::Migrations" },
                   { module => "Mojo::Pg::Results" },
                   { module => "Archive::Libarchive::FFI" },
                   { module => "FFI::CheckLib" },
                   { module => "FFI::Raw" },
                   { module => "FFI::Raw::MemPtr" },
                   { module => "FFI::Util" },
                   { module => "Moo" },
                   { module => "Moose" },
                   { module => "MooseX::Types" },
                   { module => "Mouse" },
                   { module => "Type::Library" },
                   { module => "Type::Tiny" },
                   { module => "Type::Utils" },
                   { module => "Types::Standard" },
                   { module => "Exporter" },
                   { module => "experimental" },
                   { module => "if" },
                   { module => "Getopt::Long" },
                   { module => "MooX::Options" },
                   { module => "Test::Kit" },
                   { module => "CPAN::DistnameInfo" },
                   { module => "ExtUtils::MakeMaker" },
                   { module => "MetaCPAN::Client" },
                   { module => "Path::Iterator::Rule" },
                   { module => "URI::Title" },
                   { module => "Code::TidyAll" },
                   { module => "Code::TidyAll::Plugin::CSSUnminifier" },
                   { module => "Code::TidyAll::Plugin::Go" },
                   { module => "Code::TidyAll::Plugin::JSBeautify" },
                   { module => "Code::TidyAll::Plugin::JSHint" },
                   { module => "Code::TidyAll::Plugin::JSLint" },
                   { module => "Code::TidyAll::Plugin::JSON" },
                   { module => "Code::TidyAll::Plugin::MasonTidy" },
                   { module => "Code::TidyAll::Plugin::PHPCodeSniffer" },
                   { module => "Code::TidyAll::Plugin::PerlCritic" },
                   { module => "Code::TidyAll::Plugin::PerlTidy" },
                   { module => "Code::TidyAll::Plugin::PodChecker" },
                   { module => "Code::TidyAll::Plugin::PodSpell" },
                   { module => "Code::TidyAll::Plugin::SVG" },
                   { module => "Code::TidyAll::Plugin::SortLines" },
                   { module => "Code::TidyAll::Plugin::SortLines::Naturally" },
                   { module => "Code::TidyAll::Plugin::UniqueLines" },
                   { module => "File::Zglob" },
                   { module => "Perl::Tidy" },
                   { module => "BPM::Engine" },
                   { module => "DBD::SQLite" },
                   { module => "Devel::Monitor" },
                   { module => "IO::Socket::SSL" },
                   { module => "Kavorka" },
                   { module => "LWP" },
                   { module => "Sereal" },
                   { module => "Storable" },
                   { module => "Test::LeakTrace" },
                   { module => "Test::Requires" },
                   { module => "Test::Requires::Env" },
                   { module => "Test::RequiresInternet" },
                   { module => "Text::Xslate" },
                   { module => "Tiffany" },
                   { module => "WWW::Mechanize" },
                   { module => "ZeroMQ" },
                   { module => "namespace::autoclean" },
                   { module => "Data::ICal" },
                   { module => "Data::ICal::DateTime" },
                   { module => "DateTime" },
                   { module => "DateTime::Format::ICal" },
                   { module => "Capture::Tiny" },
                   { module => "Devel::Size" },
                   { module => "Struct::Dumb" },
                   { module => "Path::Router" },
                   { module => "Plack::App::Path::Router" },
                   { module => "Plack::App::Path::Router::Custom" },
                   { module => "CLDR::Number" },
                   { module => "DateTime::Locale" },
                   { module => "Geo::Region" },
                   { module => "Locale::CLDR" },
                   { module => "Locales" },
                   { module => "AnyEvent" },
                   { module => "AnyEvent::HTTP" },
                   { module => "AnyEvent::RabbitMQ" },
                   { module => "Future" },
                   { module => "Promises" },
                 ],
  summary     => "Modules mentioned in Perl Advent Calendar 2014",
};

1;
# ABSTRACT: Modules mentioned in Perl Advent Calendar 2014

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::PerlAdvent::2014 - Modules mentioned in Perl Advent Calendar 2014

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::Import::PerlAdvent::2014 (from Perl distribution Acme-CPANModulesBundle-Import-PerlAdvent-2014), released on 2018-09-22.

=head1 DESCRIPTION

Modules mentioned in Perl Advent Calendar 2014.

This list is generated by extracting module names mentioned in [http://perladvent.org/2014/] (retrieved on 2016-11-06). Visit the URL for the full contents.

=head1 INCLUDED MODULES

=over

=item * L<File::Temp>

=item * L<Test::TempDir::Tiny>

=item * L<DBIx::Class>

=item * L<DBIx::Class::Schema::Loader>

=item * L<Mac::Safari::JavaScript>

=item * L<HTTP::Tiny>

=item * L<PSGI>

=item * L<Plack>

=item * L<Plack::Builder>

=item * L<Plack::Middleware>

=item * L<Plack::Util>

=item * L<List::UtilsBy>

=item * L<Sub::Name>

=item * L<Sub::Util>

=item * L<DBI>

=item * L<Test::DatabaseRow>

=item * L<Test::More>

=item * L<Time::Limit>

=item * L<PPI>

=item * L<Perl::Metrics::Simple>

=item * L<Mojo::Collection>

=item * L<Mojo::Pg>

=item * L<Mojo::Pg::Database>

=item * L<Mojo::Pg::Migrations>

=item * L<Mojo::Pg::Results>

=item * L<Archive::Libarchive::FFI>

=item * L<FFI::CheckLib>

=item * L<FFI::Raw>

=item * L<FFI::Raw::MemPtr>

=item * L<FFI::Util>

=item * L<Moo>

=item * L<Moose>

=item * L<MooseX::Types>

=item * L<Mouse>

=item * L<Type::Library>

=item * L<Type::Tiny>

=item * L<Type::Utils>

=item * L<Types::Standard>

=item * L<Exporter>

=item * L<experimental>

=item * L<if>

=item * L<Getopt::Long>

=item * L<MooX::Options>

=item * L<Test::Kit>

=item * L<CPAN::DistnameInfo>

=item * L<ExtUtils::MakeMaker>

=item * L<MetaCPAN::Client>

=item * L<Path::Iterator::Rule>

=item * L<URI::Title>

=item * L<Code::TidyAll>

=item * L<Code::TidyAll::Plugin::CSSUnminifier>

=item * L<Code::TidyAll::Plugin::Go>

=item * L<Code::TidyAll::Plugin::JSBeautify>

=item * L<Code::TidyAll::Plugin::JSHint>

=item * L<Code::TidyAll::Plugin::JSLint>

=item * L<Code::TidyAll::Plugin::JSON>

=item * L<Code::TidyAll::Plugin::MasonTidy>

=item * L<Code::TidyAll::Plugin::PHPCodeSniffer>

=item * L<Code::TidyAll::Plugin::PerlCritic>

=item * L<Code::TidyAll::Plugin::PerlTidy>

=item * L<Code::TidyAll::Plugin::PodChecker>

=item * L<Code::TidyAll::Plugin::PodSpell>

=item * L<Code::TidyAll::Plugin::SVG>

=item * L<Code::TidyAll::Plugin::SortLines>

=item * L<Code::TidyAll::Plugin::SortLines::Naturally>

=item * L<Code::TidyAll::Plugin::UniqueLines>

=item * L<File::Zglob>

=item * L<Perl::Tidy>

=item * L<BPM::Engine>

=item * L<DBD::SQLite>

=item * L<Devel::Monitor>

=item * L<IO::Socket::SSL>

=item * L<Kavorka>

=item * L<LWP>

=item * L<Sereal>

=item * L<Storable>

=item * L<Test::LeakTrace>

=item * L<Test::Requires>

=item * L<Test::Requires::Env>

=item * L<Test::RequiresInternet>

=item * L<Text::Xslate>

=item * L<Tiffany>

=item * L<WWW::Mechanize>

=item * L<ZeroMQ>

=item * L<namespace::autoclean>

=item * L<Data::ICal>

=item * L<Data::ICal::DateTime>

=item * L<DateTime>

=item * L<DateTime::Format::ICal>

=item * L<Capture::Tiny>

=item * L<Devel::Size>

=item * L<Struct::Dumb>

=item * L<Path::Router>

=item * L<Plack::App::Path::Router>

=item * L<Plack::App::Path::Router::Custom>

=item * L<CLDR::Number>

=item * L<DateTime::Locale>

=item * L<Geo::Region>

=item * L<Locale::CLDR>

=item * L<Locales>

=item * L<AnyEvent>

=item * L<AnyEvent::HTTP>

=item * L<AnyEvent::RabbitMQ>

=item * L<Future>

=item * L<Promises>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-PerlAdvent-2014>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-PerlAdvent-2014>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-PerlAdvent-2014>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
